#~ /***************************************************************************
 #~ *            CPConstants.py
 #~ *
 #~ *  Mon Feb 23 11:21:36 2004
 #~ *  Copyright  2004  Stas Z
 #~ *  stasz@linux.isbeter.nl
 #~ ****************************************************************************/

## CPConstants
## This file provides constants used by all the childsplay modules.

## The module "BASEPATH" is created by the installation proces.

import os,sys
def get_rootdir():
    """Returns the CWD, on Linux this will be the same as os.getcwd().
     But on win32, it can be anything when run from a standalone exe, crapware!"""
    return os.path.abspath(sys.path[0])

# constants
HOME_DIR_NAME = '.childsplay'
# Needed when on win32, this way we keep the Linux and win versions the same
if os.name == 'nt':
    try:
        os.environ['HOMEPATH']
    except KeyError:
        os.environ['HOME'] = get_rootdir()
    else:
        os.environ['HOME'] = os.environ['HOMEPATH']
        
# Check if there's a childsplay dir in the home directory
HOMEDIR = os.path.join(os.environ['HOME'],HOME_DIR_NAME)

# this is the directory tree in HOME_DIR_NAME.
# Names seperated by commas are the names from which directories are created
# if a name are followed by a ; then the next name is considered a sub dir.
# Example: 'childsplay,memory;my_images', will become
# $HOME/.childsplay/childsplay/
# $HOME/.childsplay/memory/my_images/
HOME_DIR_TREE = 'childsplay,ConfigData,memory;my_images'

## paths ##
if os.name == 'nt':
    BASEDIR = get_rootdir()
    DATADIR = os.path.join(get_rootdir(),'Data')
    MODULESDATADIR = os.path.join(get_rootdir(),'lib')
    LOCALEDIR = os.path.join(BASEDIR,'locale')
    ASSETMLROOT = os.path.join(get_rootdir(),'assetml')
    SCOREFILE = os.path.join(DATADIR,'childsplay.score')
    CHILDSPLAYRC = 'childsplayrc.txt'
    LIBDIR = os.path.join(BASEDIR,'lib')
    MODULES = LIBDIR
else:
    try:
        import BASEPATH
    except ImportError:
        BP = '/usr'
    else:
        BP = BASEPATH.BASEPATH
    BASEDIR = os.path.join(BP,'lib','','childsplay')
    DATADIR = os.path.join(BP,'lib','childsplay','Data')
    MODULESDATADIR = os.path.join(BP,'lib','childsplay','lib')
    LOCALEDIR = os.path.join('/','usr','local','share','locale')
    ASSETMLROOT = '/usr/share/assetml'
    SCOREFILE = os.path.join(DATADIR,'childsplay.score')
    CHILDSPLAYRC = 'childsplayrc'
    LIBDIR = os.path.join(BP,'lib','','childsplay','lib')
    MODULES = os.path.join(BASEDIR,'lib')
    
    
RCDIR = os.path.join(DATADIR,'ConfigData')

##  flags ##
MONITOR = None # Special monitor plugin, optional, future use
RCFILES = None # Can we use configuration files
SPLASH = True # do we want a splash  
helptext = "Not much help here yet, look at the manpage and docs."
